@@ -18,9 +18,9 @@ class Hahn(OrthogonalPolynomialsGenerator):
         if not (isinstance(N, int) and N > 0):
             warn("The size N should be an integer positive number (int).")
         if not (isinstance(alpha, Symbol) or (isinstance(alpha, float) and alpha >= -1)):
-            warn("The parameter alpha should be a real number greater tan or equal to -1 (float) or a sympy.Symbol.")
+            warn("The parameter alpha should be a real number greater than or equal to -1 (float) or a sympy.Symbol.")
         if not (isinstance(beta, Symbol) or (isinstance(beta, float) and beta >= -1)):
-            warn("The parameter beta should be a real number greater tan or equal to -1 (float) or a sympy.Symbol.")
+            warn("The parameter beta should be a real number greater than or equal to -1 (float) or a sympy.Symbol.")
         super().__init__([N, alpha, beta], x)
 
 
