@@ -110,7 +110,7 @@ class OrthogonalPolynomialsGenerator:
 
 
     def check(self, pol):
-        """Check if a polynomial belongs to Charlier Orthogonal Sequence.
+        """Check if a polynomial belongs to the orthogonal sequence.
 
         Args:
             pol (sympy.poly): a polynomial
@@ -127,11 +127,11 @@ class OrthogonalPolynomialsGenerator:
 
 
     def plot(self, degrees, xlim=(0, 10)):
-        """Plot the Charlier polynomials of given degrees
+        """Plot the polynomials of given degrees
 
         Args:
             degrees (list of int): degrees of plotted polynomials
-
+            xlim (to floats): left and right limits of X axis
         Return:
             Sympy plot
         """
